@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: log.c,v 1.17 2000/02/13 15:29:02 bazsi Exp $
+ * $Id: log.c,v 1.19 2000/03/01 22:02:47 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -44,6 +44,8 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 	int left;
 	int pri;
 	time_t now = time(NULL);
+	char *oldsrc;
+	int oldleft;
 	
 	src = data;
 	left = length;
@@ -95,9 +97,6 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 	}
 
 	if (lm->date) {
-		char *oldsrc;
-		int oldleft;
-		
 		while (left && *src == ' ') {
 			src++; /* skip whitespace */
 			left--;
@@ -136,6 +135,23 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 		left = oldleft;
 	}
 	else {
+		oldsrc = src;
+		oldleft = left;
+		if ((lm->pri & LOG_FACMASK) == LOG_KERN) {
+			lm->program = c_format_cstring("kernel");
+		}
+		else {
+			while (left && *src != ' ' && *src != '[' && *src != ':' && 
+			       *src != '/' && *src != ',' && *src != '<') {
+				src++;
+				left--;
+			}
+			if (left) {
+				lm->program = c_format_cstring("%s", oldleft - left, oldsrc);
+			}
+			left = oldleft;
+			src = oldsrc;
+		}
 		lm->stamp = now;
 	}
 
@@ -177,7 +193,7 @@ struct log_info *make_internal_message(UINT32 pri, UINT32 length, UINT8 *data)
 	NEW_SPACE(self);
 	self->msg = c_format_cstring("syslog-ng[%i]: %s", getpid(), length, data);
 	self->program = c_format_cstring("syslog-ng");
-	self->recvd = time(NULL);
+	self->stamp = self->recvd = time(NULL);
 	self->pri = pri;
 	self->flags = LF_INTERNAL;
 	self->use_cnt = 1;
