@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: syslog-ng.h,v 1.15 1999/11/15 12:30:42 bazsi Exp $
+ * $Id: syslog-ng.h,v 1.16 2000/02/22 17:50:29 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -52,5 +52,9 @@
 
 #define LOG_FIFO_SIZE		100
 
+#if !HAVE_STRCASECMP
+extern int strcasecmp(const char *s1, const char *s2);
+#endif
+
 #endif
 
